@@ -78,6 +78,13 @@ async def test_ticket_operations(async_rt_connection: rt.rest2.AsyncRt):
     assert search_result[0]['id'] == str(ticket_id)
     assert search_result[0]['Status'] == 'new'
 
+    # search with query_format field list
+    search_result = [item async for item in async_rt_connection.search(Subject=ticket_subject, query_format=['Status','Subject'])]
+    assert len(search_result) == 1
+    assert search_result[0]['Subject'] == str(ticket_subject)
+    assert search_result[0]['Status'] == 'new'
+    assert 'Requestor' not in search_result[0].keys()
+
     # raw search
     search_result = [item async for item in async_rt_connection.search(raw_query=f'Subject="{ticket_subject}"')]
     assert len(search_result) == 1
